%option noyywrap
%option c++
%option yyclass="ParseHTML"

%{

#include <strstream>

#include "parsehtml.h"



ParseHTML::ParseHTML( const string & text ) {
  istrstream flux( text.c_str() );
  yyrestart( &flux );
  yylex();
}

void ParseHTML::insertBase(){
  base=YYText();
}

void ParseHTML::insertLien() {
	vectLink.push_back( YYText() );
}


void ParseHTML::insertImage() {
	vectImg.push_back( YYText() );
}


void ParseHTML::insertmot(const char * mot) {
  
  text+=mot;
}


void ParseHTML::insertmot() {
  text+=YYText();
}


const vector<string> & ParseHTML::getLiens() const {
  	return vectLink;
}

const string & ParseHTML::getBase() const {
  return base;
}

const vector<string> & ParseHTML::getImages() const {
  return vectImg;
}

const string & ParseHTML::getMots() const {
   return text;
}




%}
CHIFFRE [0-9]
LETTRE [a-z]|[A-Z]
VIDE (" "|\t|\n)
BALISEOPEN \<!\|<
BALISECLOSE \>
BALISESIMPLE [^("script"|"applet"|"style")]
TEXT {LETTRE}+{CHIFFRE}*


%x STYLE
%x SCRIPT
%x APPLET
%x BALISE
%x LIEN
%s EXTRACT
%x IMG
%s GETIMG
%x TITLE
%x META
%s DESCRIPTION
%s KEYWORDS
%x BASE
%s GETBASE

%%
"<title>" {BEGIN TITLE;}
<TITLE>. { insertmot(yytext); }
<TITLE>\n { insertmot(" "); }
<TITLE>"&a"[^;]*";"|&#193;|&#225;|&#194;|&#226;|&#180;|&#192;|&#224; {insertmot("a"); }
<TITLE>"&e"[^;]*";"|&#201;|&#233;|&#202;|&#234;|&#200;|&#232; {insertmot("e"); }
<TITLE>"&i"[^;]*";"|&#205;|&#237;|&#206;|&#238;|&#161;|&#204;|&#236; {insertmot("i"); }
<TITLE>"&o"[^;]*";"|&#211;|&#243;|&#212;|&#244;|&#210;|&#242;|&#216;|&#248;|&#213;|&#245;|&#214;|&#246; {insertmot("o"); }
<TITLE>"&u"[^;]*";"|&#218;|&#250;|&#219;|&#251;|&#217;|&#249; {insertmot("u"); }
<TITLE>"&n"[^;]*";"|&#209;|&#241; {insertmot("n"); }
<TITLE>"&c"[^;]*";"|&#199;|&#231;|&#184; {insertmot("c"); }
<TITLE>"&y"[^;]*";"|&#221;|&#253; {insertmot("y"); }
<TITLE>"</title>" {BEGIN 0;}

"<meta" {BEGIN META;}
<META>[^>]|\n { insertmot(); }
<META>"name=\"description\""  {BEGIN DESCRIPTION;}
<META>"name=\"keywords\"" {BEGIN KEYWORDS;}
<META>">"  BEGIN 0;
<DESCRIPTION>(" "|\t)*"content=\""
<DESCRIPTION>"&a"[^;]*";"|&#193;|&#225;|&#194;|&#226;|&#180;|&#192;|&#224; {insertmot("a");}
<DESCRIPTION>"&e"[^;]*";"|&#201;|&#233;|&#202;|&#234;|&#200;|&#232; {insertmot("e");}
<DESCRIPTION>"&o"[^;]*";"|&#211;|&#243;|&#212;|&#244;|&#210;|&#242;|&#216;|&#248;|&#213;|&#245;|&#214;|&#246; {insertmot("o");}
<DESCRIPTION>"&i"[^;]*";"|&#205;|&#237;|&#206;|&#238;|&#161;|&#204;|&#236; {insertmot("i");}
<DESCRIPTION>"&u"[^;]*";"|&#218;|&#250;|&#219;|&#251;|&#217;|&#249; {insertmot("u");}
<DESCRIPTION>"&n"[^;]*";"|&#209;|&#241; {insertmot("n");}
<DESCRIPTION>"&c"[^;]*";"|&#199;|&#231;|&#184; {insertmot("c");}
<DESCRIPTION>"&y"[^;]*";"|&#221;|&#253; {insertmot("y");}
<DESCRIPTION>"\"" BEGIN META;
<DESCRIPTION>.|\n  insertmot();
<KEYWORDS>(" "|\t)*"content=\""
<KEYWORDS>"&o"[^;]*";"|&#211;|&#243;|&#212;|&#244;|&#210;|&#242;|&#216;|&#248;|&#213;|&#245;|&#214;|&#246; {insertmot("o");}
<KEYWORDS>"&a"[^;]*";"|&#193;|&#225;|&#194;|&#226;|&#180;|&#192;|&#224; {insertmot("a");}
<KEYWORDS>"&i"[^;]*";"|&#205;|&#237;|&#206;|&#238;|&#161;|&#204;|&#236; {insertmot("i");}
<KEYWORDS>"&e"[^;]*";"|&#201;|&#233;|&#202;|&#234;|&#200;|&#232; {insertmot("e");}
<KEYWORDS>"&u"[^;]*";"|&#218;|&#250;|&#219;|&#251;|&#217;|&#249; {insertmot("u");}
<KEYWORDS>"&n"[^;]*";"|&#209;|&#241; {insertmot("n");}
<KEYWORDS>"&c"[^;]*";"|&#199;|&#231;|&#184; {insertmot("c");}
<KEYWORDS>"&y"[^;]*";"|&#221;|&#253; {insertmot("y");}
<KEYWORDS>"\"" BEGIN META;
<KEYWORDS>.|\n  insertmot();

"<base" {BEGIN BASE;}
<BASE>">" {BEGIN 0;}
<BASE>"href=\"" {BEGIN GETBASE;}
<BASE>[^>]|\n
<GETBASE>[^"]* (insertBase();BEGIN BASE;}

"<style" { BEGIN  STYLE; }
<STYLE>"style>" {  BEGIN 0; }
<STYLE>.|\n 

"<script" { BEGIN  SCRIPT; }
<SCRIPT>"script>" {  BEGIN 0; }
<SCRIPT>.|\n

 "<applet" { BEGIN  APPLET; }
<APPLET>"applet>" {  BEGIN 0; }
<APPLET>.|\n

("<a "|"<A") {BEGIN LIEN;}
<LIEN>"href=\"" {BEGIN EXTRACT;}
<LIEN>[^>]|\n 
<LIEN>">"  { BEGIN 0; } 
<EXTRACT>[^"]*  {insertLien();BEGIN LIEN;}

"<img " {BEGIN IMG;}
<IMG>"src=\"" {BEGIN GETIMG;}
<IMG>">" {BEGIN 0;}
<IMG>[^>]|\n {;}
<GETIMG>[^"]*  {insertImage(); BEGIN IMG;}

"<" { BEGIN BALISE; }
<BALISE>">" { BEGIN 0; }
<BALISE>.|\n 

"&a"[^;]*";"|&#193;|&#225;|&#194;|&#226;|&#180;|&#192;|&#224; insertmot("a");
"&e"[^;]*";"|&#201;|&#233;|&#202;|&#234;|&#200;|&#232; insertmot("e");
"&i"[^;]*";"|&#205;|&#237;|&#206;|&#238;|&#161;|&#204;|&#236; insertmot("i");
"&o"[^;]*";"|&#211;|&#243;|&#212;|&#244;|&#210;|&#242;|&#216;|&#248;|&#213;|&#245;|&#214;|&#246; insertmot("o");
"&u"[^;]*";"|&#218;|&#250;|&#219;|&#251;|&#217;|&#249; insertmot("u");
"&n"[^;]*";"|&#209;|&#241; insertmot("n");
"&c"[^;]*";"|&#199;|&#231;|&#184; insertmot("c");
"&y"[^;]*";"|&#221;|&#253; insertmot("y");
"&"[^;]*";"   insertmot(" ");
[^a-zA-Z ]  insertmot(" ");
(\n|[^a-zA-Z]){LETTRE}([^a-zA-Z]|\n)  insertmot(" ");
{VIDE}+  insertmot(" ");
{TEXT} insertmot();
%% 
